@@ -12,6 +12,6 @@ cart2clock <- function(x, y = NULL, circle)
   xy <- getXY(x, y, unidim.allowed=FALSE)
   x <- xy$x
   y <- xy$y
-  phi <-(atan(x/y)/2/pi*circle + ifelse(y>0,circle,1.5*circle))%%circle
+  phi <-(atan(x/y)/2/pi*circle + ifelse(y>=0,circle,1.5*circle))%%circle
   return(data.frame(rho=sqrt(x*x+y*y),phi=phi))
 } ## cart2clock
